pub struct GnomonicPoint {
pub east: f64,
pub north: f64,
}Expand description
A position in a gnomonic tangent plane.
Both coordinates are dimensionless ratios on the projection plane. For small offsets, their numeric values approximate angular offsets in radians.
Fields
east: f64Coordinate toward increasing right ascension (East).
north: f64Coordinate toward the North celestial pole.